@@ -1,3 +1,6 @@
+import collections
+
+
 PSEUDO_SELECTORS = (':all', ':pk', ':local', ':related')
 DEFAULT_SELECTORS = (':pk', ':local')
 
@@ -14,10 +17,10 @@ class ModelFieldResolver(object):
 
     def _get_pk_field(self, model):
         fields = (model._meta.pk,)
-        names = tuple(map(lambda x: x.name, fields))
+        names = tuple([x.name for x in fields])
 
         return {
-            ':pk': dict(zip(names, fields)),
+            ':pk': dict(list(zip(names, fields))),
         }
 
     def _get_local_fields(self, model):
@@ -26,10 +29,10 @@ class ModelFieldResolver(object):
         m2m = model._meta.many_to_many
 
         fields = local + m2m
-        names = tuple(map(lambda x: x.name, fields))
+        names = tuple([x.name for x in fields])
 
         return {
-            ':local': dict(zip(names, fields)),
+            ':local': dict(list(zip(names, fields))),
         }
 
     def _get_related_fields(self, model):
@@ -38,10 +41,10 @@ class ModelFieldResolver(object):
         reverse_m2m = model._meta.get_all_related_many_to_many_objects()
 
         fields = tuple(reverse_fk + reverse_m2m)
-        names = tuple(map(lambda x: x.get_accessor_name(), fields))
+        names = tuple([x.get_accessor_name() for x in fields])
 
         return {
-            ':related': dict(zip(names, fields)),
+            ':related': dict(list(zip(names, fields))),
         }
 
     def _get_fields(self, model):
@@ -53,7 +56,7 @@ class ModelFieldResolver(object):
             fields.update(self._get_related_fields(model))
 
             all_ = {}
-            for x in fields.values():
+            for x in list(fields.values()):
                 all_.update(x)
 
             fields[':all'] = all_
@@ -67,7 +70,7 @@ class ModelFieldResolver(object):
 
         # Alias to model fields
         if attr in PSEUDO_SELECTORS:
-            return fields[attr].keys()
+            return list(fields[attr].keys())
 
         # Assume a field or property
         return attr
@@ -118,7 +121,7 @@ def get_field_value(obj, name, allow_missing=False):
         raise ValueError('{} has no attribute {}'.format(obj, name))
 
     # Check for callable
-    if callable(value):
+    if isinstance(value, collections.Callable):
         value = value()
 
     # Handle a local many-to-many or a reverse foreign key
